@@ -51,8 +51,8 @@ mod ieee754_section_5_10_total_order_tests {
     use super::dom::Dom;
 
     use crate::value::{Value, PlainValue};
-    fn f(val: f32) -> Value<PlainValue<Dom>, Dom> { Value::from(val) }
-    fn d(val: f64) -> Value<PlainValue<Dom>, Dom> { Value::from(val) }
+    fn f(val: f32) -> Value<PlainValue<Dom>> { Value::from(val) }
+    fn d(val: f64) -> Value<PlainValue<Dom>> { Value::from(val) }
 
     // TODO: Test cases with a few different signalling and non-signalling NaNs
 
@@ -145,7 +145,7 @@ mod value_tests {
     use crate::value::{Value, PlainValue, repr::Record, signed_integer::SignedInteger};
     use super::dom::Dom;
 
-    type VV = Value<PlainValue<Dom>, Dom>;
+    type VV = Value<PlainValue<Dom>>;
 
     #[test] fn boolean_mut() {
         let mut b = VV::Boolean(true);
