@@ -1,11 +1,11 @@
-use crate::value::{IOValue, UnwrappedIOValue, NestedValue};
+use crate::value::{IOValue, NestedValue};
 
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone)]
 pub struct Symbol(pub String);
 
 impl serde::Serialize for Symbol {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: serde::Serializer {
-        UnwrappedIOValue::symbol(&self.0).wrap().serialize(serializer)
+        IOValue::symbol(&self.0).serialize(serializer)
     }
 }
 
